==> spellathon-5.47.tar.gz: spellathon-5.47/src/gui/wordinput.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef WORDINPUT_H
#define WORDINPUT_H

#include <QObject>
#include <QLineEdit>

class QTimer;

class WordInput : public QLineEdit {
	Q_OBJECT
public:
	WordInput(QWidget *p = 0);

	void setInitState(bool s);
	bool initState() const { return init_state; }
private:
	void setIpState(bool e);
	virtual void paintEvent(QPaintEvent *ev);
	virtual void mousePressEvent(QMouseEvent *ev);
	virtual void keyPressEvent(QKeyEvent *ev);
	virtual void focusInEvent(QFocusEvent *ev);
public slots:
	void chk_clear(); 
	void chk(int v);
public:
	enum { WRONG=-1, REPEAT, CORRECT, BLANK };
private:
	int		chk_state;
	int		init_state;
	bool	ip_state;
	QTimer	*timer;
	QString	buf;
	WordInput(const WordInput &);
	WordInput & operator=(const WordInput &);
};

#endif /* WORDINPUT_H */

==> spellathon-5.59.tar.gz: spellathon-5.59/src/gui/wordinput.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef WORDINPUT_H
#define WORDINPUT_H

#include <QObject>
#include <QLineEdit>
#include <QLabel>
#include <QGridLayout>
#include <QTimer>

class WordEdit : public QLineEdit {
	Q_OBJECT
public:
	WordEdit(QWidget *p = 0);
	~WordEdit() {}

	void setInitState(bool s);
private:
	virtual void mousePressEvent(QMouseEvent *ev);
	virtual void keyPressEvent(QKeyEvent *ev);
	virtual void focusInEvent(QFocusEvent *ev);
public slots:
	void chk(int);
	void chk_clear();
private slots:
	void tmout_clear();
signals:
	void setIndicator(int v);
private:
	int		init_state;
	QTimer	*timer;

	WordEdit(const WordEdit &);
	WordEdit & operator=(const WordEdit &);
};

class WordInput : public QWidget {
	Q_OBJECT
public:
	WordInput(QWidget *p = 0);
	~WordInput() {}

public slots:
	void setIndicator(int v);
public:
	enum { WRONG=-1, REPEAT, CORRECT, BLANK };
	WordEdit	*wordEdit;
	QLabel		*chkText;
	QLabel		*chkImg;
private:
	virtual QSize sizeHint() const;
	virtual void paintEvent(QPaintEvent *ev);
private:
	QGridLayout *grdlayout;
	QSpacerItem	*hzspcer;
	int			chkState;

	WordInput(const WordInput &);
	WordInput & operator=(const WordInput &);
};

#endif /* WORDINPUT_H */
